#ifndef BOOKLISTITEM_H
#define BOOKLISTITEM_H

#include <QWidget>
#include <QApplication>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QLabel>
#include <QFrame>
#include <QPainter>
#include <QLinearGradient>
#include <QAbstractKineticScroller>
#include "book.h"

//TODO:Remove dependancy on Book, class should be independent from others 
//Replace with a delegate?

class BookListItem : public QWidget{
    Q_OBJECT
public:
    BookListItem(Book *book, QWidget *parent = 0, QAbstractKineticScroller *scrollable = 0) : QWidget(parent){
        thisBook = book;

        mainLayout = new QHBoxLayout();
        QMargins margins(0, 0, 0, 0);
        mainLayout->setContentsMargins(margins);
        QPixmap temp = book->getCoverImage();
        if(!temp.isNull()){
            QLabel *image = new QLabel(this);
            temp = temp.scaledToWidth(100);
            image->setPixmap(temp);
            image->setFixedWidth(temp.width());
            mainLayout->addWidget(image);
            mainLayout->setAlignment(image, Qt::AlignLeft | Qt::AlignTop);
        }

        connect(thisBook, SIGNAL(coverImageAdded()), this, SLOT(coverImageAdded()));

        QVBoxLayout *subLayout = new QVBoxLayout();
        subLayout->setContentsMargins(margins);
        mainLayout->addLayout(subLayout);

        QLabel *title = new QLabel(book->getTitle(), this);
        title->setWordWrap(true);
        title->setMinimumWidth(250);
        title->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        subLayout->addWidget(title);
        subLayout->setAlignment(title, Qt::AlignLeft);

        QLabel *author = new QLabel(book->getAuthor(), this);
        author->setWordWrap(true);
        author->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        subLayout->addWidget(author);

        QString subject = book->getSubject();
        if(!subject.isEmpty() && !subject.isNull()){
            QLabel *category = new QLabel(subject, this);
            category->setFont(QFont("Sans", 12));
            category->setWordWrap(true);
            category->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
            subLayout->addWidget(category);
        }

        QVBoxLayout *superLayout = new QVBoxLayout(this);

        topSeparator = new QFrame(this);
        topSeparator->setFrameStyle(QFrame::HLine | QFrame::Plain);
        topSeparator->setLineWidth(4);
        QPalette topSeparatorPalette = QApplication::palette();
        topSeparatorPalette.setColor(QPalette::WindowText, QColor(Qt::transparent));
        topSeparator->setPalette(topSeparatorPalette);
        superLayout->addWidget(topSeparator);

        superLayout->addLayout(mainLayout);

        separator = new QFrame(this);
        separator->setFrameStyle(QFrame::HLine | QFrame::Plain);
        separator->setLineWidth(4);
        QPalette separatorPalette = QApplication::palette();
        separatorPalette.setColor(QPalette::WindowText, QColor(Qt::transparent));
        separator->setPalette(separatorPalette);
        superLayout->addWidget(separator);

        superLayout->setContentsMargins(margins);

        setLayout(superLayout);

        scroller = scrollable;

/*        QPalette palette = QApplication::palette();
        QColor normalbg = palette.window().color();
        palette.setCurrentColorGroup(QPalette::Active);
        QColor highlight = palette.highlight().color(); 
        //highlight.setAlpha(0.5);

        gradient = QLinearGradient(QPointF(0, 0), QPointF(0, height()));

        gradient.setColorAt(0, highlight);
        gradient.setColorAt(1, highlight);

        setAutoFillBackground(true);*/
    }
protected:
    void mouseReleaseEvent(QMouseEvent *event){
        if(scroller){
            if(scroller->state() == QAbstractKineticScroller::Inactive)
                emit selected(thisBook);
        }
        QPalette palette = QApplication::palette();
        palette.setColor(QPalette::WindowText, QColor(Qt::transparent));
        separator->setPalette(palette);
        topSeparator->setPalette(palette);

/*        palette = QApplication::palette();
        palette.setColor(QPalette::Window, palette.color(QPalette::Button));
        setPalette(palette);*/
    }
    void mousePressEvent(QMouseEvent *event){
        QPalette palette;
        palette.setCurrentColorGroup(QPalette::Active);
        QBrush brush = palette.highlight();
        palette.setColor(QPalette::WindowText, brush.color());
        separator->setPalette(palette);
        topSeparator->setPalette(palette);
/*        palette.setBrush(QPalette::Window, QBrush(gradient));
        setPalette(palette);*/
    }

private:
    Book *thisBook;
    QAbstractKineticScroller *scroller;
    QHBoxLayout *mainLayout;
    QFrame *separator;
    QFrame *topSeparator;
    QLinearGradient gradient;

signals:
    void selected(Book*);

public slots:
    void coverImageAdded(){
        QPixmap temp = thisBook->getCoverImage();
        if(!temp.isNull()){
            QLabel *image = new QLabel(this);
            temp = temp.scaledToWidth(100);
            image->setPixmap(temp);
            image->setFixedWidth(temp.width());
            mainLayout->insertWidget(0, image);
            mainLayout->setAlignment(image, Qt::AlignLeft | Qt::AlignTop);
            adjustSize();
        }
    }
};

#endif
